==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/V_INSSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ModelClassSetImpl;
import io.ciera.tool.sql.ooaofooa.value.V_INS;
import io.ciera.tool.sql.ooaofooa.value.V_INSSet;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;

import java.util.Arrays;
import java.util.List;


public class V_INSSetImpl extends InstanceSet<V_INSSet,V_INS> implements V_INSSet {

    // attributes
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( V_INS v_ins : this ) v_ins.setVar_ID( ref_Var_ID );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( V_INS v_ins : this ) v_ins.setObj_ID( ref_Obj_ID );
    }


    // selections
    @Override
    public V_VARSet R814_is_a_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( V_INS v_ins : this ) v_varset.add( v_ins.R814_is_a_V_VAR() );
        return v_varset;
    }
    @Override
    public ModelClassSet R819_refers_to_ModelClass() throws XtumlException {
        ModelClassSet modelclassset = new ModelClassSetImpl();
        for ( V_INS v_ins : this ) modelclassset.add( v_ins.R819_refers_to_ModelClass() );
        return modelclassset;
    }


    @Override
    public V_INS nullElement() {
        return V_INSImpl.EMPTY_V_INS;
    }

    @Override
    public V_INSSet emptySet() {
      return new V_INSSetImpl();
    }

    @Override
    public V_INSSet value() {
        return this;
    }

    @Override
    public List<V_INS> elements() {
        return Arrays.asList(toArray(new V_INS[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/V_INSSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ModelClassSetImpl;
import io.ciera.tool.sql.ooaofooa.value.V_INS;
import io.ciera.tool.sql.ooaofooa.value.V_INSSet;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class V_INSSetImpl extends InstanceSet<V_INSSet,V_INS> implements V_INSSet {

    public V_INSSetImpl() {
    }

    public V_INSSetImpl(Comparator<? super V_INS> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( V_INS v_ins : this ) v_ins.setVar_ID( ref_Var_ID );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( V_INS v_ins : this ) v_ins.setObj_ID( ref_Obj_ID );
    }


    // selections
    @Override
    public V_VARSet R814_is_a_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( V_INS v_ins : this ) v_varset.add( v_ins.R814_is_a_V_VAR() );
        return v_varset;
    }
    @Override
    public ModelClassSet R819_refers_to_ModelClass() throws XtumlException {
        ModelClassSet modelclassset = new ModelClassSetImpl();
        for ( V_INS v_ins : this ) modelclassset.add( v_ins.R819_refers_to_ModelClass() );
        return modelclassset;
    }


    @Override
    public V_INS nullElement() {
        return V_INSImpl.EMPTY_V_INS;
    }

    @Override
    public V_INSSet emptySet() {
      return new V_INSSetImpl();
    }

    @Override
    public V_INSSet emptySet(Comparator<? super V_INS> comp) {
      return new V_INSSetImpl(comp);
    }

    @Override
    public V_INSSet value() {
        return this;
    }

    @Override
    public List<V_INS> elements() {
        return Arrays.asList(toArray(new V_INS[0]));
    }

}
